skillfed

tokenspeed-triton

A language and compiler for custom Deep Learning operations (vendor release for TokenSpeed)

tokenspeed-triton v3.8.10.post20260721 2.0M downloads/30d#3,380 on PyPI19,944
Permissive license MIT Active released

What it is and what it does

Triton is a compiler and language designed to let you write high-performance deep-learning kernels at a higher level of abstraction than CUDA, while retaining the ability to optimize for specific hardware. Instead of writing low-level GPU code, you write Triton kernels in Python-like syntax, and the compiler handles the translation to efficient machine code for GPUs and CPUs. It sits between the productivity of high-level frameworks and the control of hand-written CUDA.

The package is intended for researchers and engineers building custom neural-network operations—operations that existing frameworks don't provide or that need domain-specific optimization. It includes a just-in-time compiler, an interpreter for CPU-based testing, and support for tiled computation patterns common in deep learning. The main runtime dependency is importlib-metadata; the package itself handles LLVM integration during build time.

Use it for:

  • Write custom CUDA-like kernels for novel neural-network layers without learning low-level GPU programming.
  • Optimize matrix operations, attention mechanisms, or other primitives for specific hardware without rewriting in C++.
  • Prototype and test GPU kernels on CPU using the Triton interpreter before deploying to hardware.
  • Build domain-specific deep-learning libraries that need fine-grained control over memory and compute.
  • Accelerate research by rapidly iterating on custom operations in a higher-level language than CUDA.

Worth the install?

AI-flagged interpretation of the facts on this page — verify before relying

Triton is a language and compiler for writing custom deep-learning operations that compile to efficient GPU and CPU code, offering higher productivity than CUDA with greater flexibility than other domain-specific languages.

Yes, if you are writing custom deep-learning operations and want to avoid low-level CUDA programming. The package is actively maintained, permissively licensed, has no known vulnerabilities, and runs on modern Python versions. Install friction is moderate due to binary wheels being available but source builds requiring LLVM; this is a one-time cost. Not recommended if you only use standard framework operations or lack GPU hardware for testing.

Install

tokenspeed-triton on PyPI

pip

pip install tokenspeed-triton

uv

uv add tokenspeed-triton

poetry

poetry add tokenspeed-triton

Installing tokenspeed-triton

Before you install

Medium install friction: wheels are available for Python 3.10–3.14 on x86_64 and aarch64 Linux, but building from source requires LLVM and build-time dependencies. The package is actively maintained with a recent release (24 days old) and a well-established repository.

License in practice

MIT license is permissive; you can use, modify, and distribute this package with minimal restrictions, provided you include the license notice.

Quickstart

pip install tokenspeed-triton

import triton
import triton.language as tl

@triton.jit
def kernel(x_ptr, y_ptr, n_elements, BLOCK_SIZE: tl.constexpr):
    pid = tl.program_id(axis=0)
    block_start = pid * BLOCK_SIZE
    offsets = block_start + tl.arange(0, BLOCK_SIZE)
    mask = offsets < n_elements
    x = tl.load(x_ptr + offsets, mask=mask)
    y = x * 2
    tl.store(y_ptr + offsets, y, mask=mask)

Requires a compatible GPU (NVIDIA or AMD) and CUDA/ROCm runtime for execution; CPU-only testing is possible with TRITON_INTERPRET=1 environment variable.

Verify before relying

  • Whether prebuilt wheels cover all target deployment architectures and CUDA versions needed for your use case.
  • Performance gains relative to hand-written CUDA or other kernel frameworks for your specific workloads.
  • Maturity of AMD GPU support and whether it matches NVIDIA feature parity.

Package facts

License MIT (permissive)
Python support supports the current Python release (<3.15,>=3.10)
Install friction medium — platform-specific wheel
Runtime dependencies 1 — importlib-metadata
Maintenance actively maintained — 24 days since the last release
Last repo commit
First released
Downloads 1,990,943/month — #3,380 on PyPI (30-day window, as of 2026-08-14)
Known vulnerabilities none known (OSV.dev, checked 2026-08-14)

Evidence: tokenspeed_triton-3.8.10.post20260721-cp310-cp310-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; tokenspeed_triton-3.8.10.post20260721-cp310-cp310-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl; tokenspeed_triton-3.8.10.post20260721-cp311-cp311-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; tokenspeed_triton-3.8.10.post20260721-cp311-cp311-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl; tokenspeed_triton-3.8.10.post20260721-cp312-abi3-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; tokenspeed_triton-3.8.10.post20260721-cp312-abi3-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl

Keywords: Compiler, Deep Learning

Development Status :: 4 - BetaIntended Audience :: DevelopersProgramming Language :: Python :: 3.10Programming Language :: Python :: 3.11Programming Language :: Python :: 3.12Programming Language :: Python :: 3.13Programming Language :: Python :: 3.14Topic :: Software Development :: Build Tools

Tags

GPU kernel compiler for deep learningcustom neural network operationsCUDA alternative high-leveldeep learning kernel languageefficient GPU code generationML primitive compilertiled neural network computations
gpu-kernel-compilerdeep-learning-infrastructure

More Build Tools packages

Further reading